--[[
sorghumStraw

Specialization to allow straw for sorghum

Author: 	Stachu
Date: 		25.03.2022
Version:	1.0
]]

sorghumStraw = {};

function sorghumStraw:loadFruitTypeWindrow(superFunc, fruitType, xmlFile, key)
	local sorghum = g_fruitTypeManager:getFruitTypeByName("sorghum");

	if sorghum ~= nil then
		local windrowFillType = g_fillTypeManager:getFillTypeByName("straw");
		
		sorghum.hasWindrow = true;
		sorghum.windrowName = windrowFillType.name;
		sorghum.windrowLiterPerSqm = 3.68;
		self.windrowFillTypes[windrowFillType.index] = true;
		self.fruitTypeIndexToWindrowFillTypeIndex[sorghum.index] = windrowFillType.index;
		self.fillTypeIndexToFruitTypeIndex[windrowFillType.index] = sorghum.index;
	end;
	
	if fruitType ~= nil and fruitType.name ~= "SORGHUM" then
		local windrowName = getXMLString(xmlFile, key .. ".windrow#name");
		local windrowLitersPerSqm = getXMLFloat(xmlFile, key .. ".windrow#litersPerSqm");

		if windrowName == nil or windrowLitersPerSqm == nil then
			return true;
		end;

		local windrowFillType = g_fillTypeManager:getFillTypeByName(windrowName);

		if windrowFillType == nil then
			print("Warning: Missing fillType '" .. tostring(windrowName) .. "' for windrow definition. Ignoring windrow!");

			return false;
		end;

		fruitType.hasWindrow = true;
		fruitType.windrowName = windrowFillType.name;
		fruitType.windrowLiterPerSqm = windrowLitersPerSqm;
		self.windrowFillTypes[windrowFillType.index] = true;
		self.fruitTypeIndexToWindrowFillTypeIndex[fruitType.index] = windrowFillType.index;
		self.fillTypeIndexToFruitTypeIndex[windrowFillType.index] = fruitType.index;
	end;

	return true;
end;

FruitTypeManager.loadFruitTypeWindrow = Utils.overwrittenFunction(FruitTypeManager.loadFruitTypeWindrow, sorghumStraw.loadFruitTypeWindrow)